@@ -7,9 +7,9 @@
 #include <QDeclarativeContext>
 #include <QtDeclarative>
 
-#ifdef Q_WS_MAEMO_5
-#include <QtOpenGL/QGLWidget>
-#endif
+//#ifdef Q_WS_MAEMO_5
+//#include <QtOpenGL/QGLWidget>
+//#endif
 
 int main(int argc, char *argv[])
 {
@@ -33,7 +33,7 @@ int main(int argc, char *argv[])
     qmlRegisterType<QDeclarativeFolderListModel>("Models",1,0,"FolderListModel");
 
 #ifdef Q_WS_MAEMO_5
-//    viewer.engine()->addImportPath(QString("/opt/qtm11/imports"));
+//    viewer.engine()->addImportPath(QLatin1String("/opt/qtm12/imports"));
     viewer.engine()->setOfflineStoragePath("/home/user/.config/cutetube");
     QDir path;
     path.setPath("/home/user/.config/cutetube");
@@ -44,7 +44,7 @@ int main(int argc, char *argv[])
     if (!path.exists()) {
         path.mkpath("/home/user/MyDocs/.cutetube");
     }
-    viewer.setViewport(new QGLWidget());
+//    viewer.setViewport(new QGLWidget());
 #endif
     viewer.setMainQmlFile(QLatin1String("qml/qmltube/main.qml"));
     viewer.showFullScreen();
