@@ -186,6 +186,7 @@ function loadVideoInfo(video) {
     var loader = viewsModel.children[windowView.currentIndex + 1];
     windowView.currentItem.visible = false;
     loader.source = "VideoInfoView.qml";
+//    loader.item.playVideo.connect(loadPlaybackView);
     loader.item.goToVideo.connect(loadVideoInfo);
     loader.item.authorClicked.connect(loadUserVideos);
     loader.item.search.connect(search);
@@ -194,6 +195,17 @@ function loadVideoInfo(video) {
     windowView.incrementCurrentIndex();
 }
 
+function loadPlaybackView(videoList) {
+    var loader = viewsModel.children[windowView.currentIndex + 1];
+    windowView.currentItem.visible = false;
+    toggleControls(false);
+    loader.source = "VideoPlaybackView.qml";
+    notificationArea.addTitle("Video Playback");
+    loader.item.setPlaylist(videoList);
+    windowView.incrementCurrentIndex();
+    loader.item.playbackStopped.connect(stopPlaying);
+}
+
 function loadDownloads() {
     var loader = viewsModel.children[windowView.currentIndex + 1];
     windowView.currentItem.visible = false;
@@ -256,3 +268,8 @@ function toggleControls(showOrHide) {
     notificationArea.visible = showOrHide;
     menuBar.visible = showOrHide;
 }
+
+function stopPlaying() {
+    toggleControls(true);
+    goToPreviousView();
+}
