@@ -53,10 +53,15 @@ function addVideosToPlaybackQueue() {
     playVideos(list);
 }
 
-function addVideosToDownloads() {
+function addVideosToDownloads(convertToAudio) {
     for (var i = 0; i < videoList.checkList.length; i++) {
         var video = videoListModel.get(videoList.checkList[i]);
-        addDownload(video);
+        if (convertToAudio) {
+            addAudioDownload(video);
+        }
+        else {
+            addDownload(video);
+        }
     }
 }
 
@@ -77,6 +82,15 @@ function addVideosToFavourites() {
     }
 }
 
+function copyVideosToClipboard() {
+    var urls = "";
+    for (var i = 0; i < videoList.checkList.length; i++) {
+        var url = videoListModel.get(videoList.checkList[i]).playerUrl.split("&")[0];
+        urls = urls + url + "\n";
+    }
+    Controller.copyToClipboard(urls);
+}
+
 function rotateDialogs() {
     if (dialog.source != "") {
         dialog.item.state = window.state;
